@@ -1,5 +1,4 @@
-from .base_functions import nest_commands, entity_list
-from .get_block import get_block, meta_get_block
+from .base_functions import nest_commands, entity_list, nesting_process
 from .set_block import set_block, meta_set_block
 from .set_image import set_image, meta_set_image, print_palette
 from .set_text import set_text, meta_set_text
@@ -17,8 +16,18 @@ from .set_gui import show_gui, meta_show_gui
 from .set_gui import clear_gui, meta_clear_gui
 
 from .miscellaneous import say, meta_say
-from .miscellaneous import ban, ban_ip, meta_ban, banlist, meta_banlist, kick, meta_kick
+from .miscellaneous import ban, ban_ip, meta_ban, banlist, meta_banlist, kick, meta_kick, pardon, meta_pardon, pardon_ip, meta_pardon_ip
 from .miscellaneous import op, deop, meta_op, meta_deop
 from .miscellaneous import seed, meta_seed
 from .miscellaneous import set_difficulty, meta_set_difficulty, get_difficulty, meta_get_difficulty
-from .miscellaneous import weather, meta_weather
\ No newline at end of file
+from .miscellaneous import weather, meta_weather
+from .miscellaneous import msg, meta_msg
+from .miscellaneous import gamemode, meta_gamemode, default_gamemode, meta_default_gamemode
+from .miscellaneous import query_time, meta_query_time, set_time, meta_set_time, add_time, meta_add_time, time, meta_time
+from .miscellaneous import xp_query, meta_xp_query
+from .miscellaneous import get_whitelist, meta_get_whitelist, toggle_whitelist, meta_toggle_whitelist, update_whitelist, meta_update_whitelist
+from .miscellaneous import stop, meta_stop, save_all, meta_save_all, toggle_save, meta_toggle_save
+from .miscellaneous import help, meta_help
+from .miscellaneous import list_players, meta_list_players
+from .miscellaneous import spectate, meta_spectate
+from .miscellaneous import set_world_spawn, meta_set_world_spawn
\ No newline at end of file
